@@ -15,6 +15,8 @@ class ScoringFunctionComponentNameEnum:
     NUM_HBD_LIPINSKI = "num_hbd_lipinski"
     NUM_HBA_LIPINSKI = "num_hba_lipinski"
     NUM_RINGS = "num_rings"
+    NUM_AROMATIC_RINGS = "num_aromatic_rings"
+    NUM_ALIPHATIC_RINGS = "num_aliphatic_rings"
     TPSA = "tpsa"
     SLOGP = "slogp"
     GRAPH_LENGTH = "graph_length"
@@ -52,6 +54,7 @@ class ScoringFunctionComponentNameEnum:
     RAT_PK_PIP = "rat-pk"
     CLAB_TOP_20 = "clab_top_20"
     RA_SCORE = "rascore"
+    AIZYNTH = "aizynth"
 
     def __getattr__(self, name):
         if name in self:
