@@ -1,6 +1,8 @@
 from typing import List
 
 from reinvent_scoring.scoring.component_parameters import ComponentParameters
+from reinvent_scoring.scoring.enums import ScoringFunctionComponentNameEnum
+from reinvent_scoring.scoring.score_components import BaseScoreComponent
 from reinvent_scoring.scoring.score_components import TanimotoSimilarity, \
     JaccardDistance, CustomAlerts, QedScore, MatchingSubstructure, \
     RocsSimilarity, ParallelRocsSimilarity, PredictivePropertyComponent, SelectivityComponent, \
@@ -8,9 +10,9 @@ from reinvent_scoring.scoring.score_components import TanimotoSimilarity, \
     NumRings, AZlogD74, HLMClint, SlogP, \
     RHClint, HHClint, SolubilityDD, HERG, CACO2Intrinsic, CACO2Efflux, AZdock, RatPKPiP, Top20, GraphLength, \
     NumberOfStereoCenters, \
-    LinkerLengthRatio, LinkerGraphLength, LinkerEffectiveLength, DockStream
-from reinvent_scoring.scoring.score_components import BaseScoreComponent
-from reinvent_scoring.scoring.enums import ScoringFunctionComponentNameEnum
+    LinkerLengthRatio, LinkerGraphLength, LinkerEffectiveLength, DockStream, BuildingBlockAvailabilityComponent, \
+    NumAromaticRings, NumAliphaticRings
+from reinvent_scoring.scoring.score_components.console_invoked import AZgard
 from reinvent_scoring.scoring.score_components.pip.pip_log_prediction_component import PiPLogPredictionComponent
 from reinvent_scoring.scoring.score_components.pip.pip_prediction_component import PiPPredictionComponent
 
@@ -37,6 +39,8 @@ class ScoreComponentFactory:
             enum.NUM_HBD_LIPINSKI: HBD_Lipinski,
             enum.NUM_HBA_LIPINSKI: HBA_Lipinski,
             enum.NUM_RINGS: NumRings,
+            enum.NUM_AROMATIC_RINGS: NumAromaticRings,
+            enum.NUM_ALIPHATIC_RINGS: NumAliphaticRings,
             enum.SLOGP: SlogP,
             enum.NUMBER_OF_STEREO_CENTERS: NumberOfStereoCenters,
             enum.PARALLEL_ROCS_SIMILARITY: ParallelRocsSimilarity,
@@ -66,13 +70,21 @@ class ScoreComponentFactory:
             enum.LINKER_GRAPH_LENGTH: LinkerGraphLength,
             enum.LINKER_EFFECTIVE_LENGTH: LinkerEffectiveLength,
             enum.LINKER_LENGTH_RATIO: LinkerLengthRatio,
-            enum.DOCKSTREAM: DockStream
+            enum.DOCKSTREAM: DockStream,
+            enum.AZGARD: AZgard,
+            enum.AIZYNTH: BuildingBlockAvailabilityComponent
         }
         return component_map
 
     def create_score_components(self) -> [BaseScoreComponent]:
-        try:
-            components = [self._current_components.get(p.component_type)(p) for p in self._parameters]
-        except KeyError as ex:
-            raise ex
+        def create_component(component_params):
+            if component_params.component_type in self._current_components:
+                component = self._current_components[component_params.component_type]
+                component_instance = component(component_params)
+            else:
+                raise KeyError(f'Component: {component_params.component_type} is not implemented.'
+                               f' Consider checking your input.')
+            return component_instance
+
+        components = [create_component(component) for component in self._parameters]
         return components
