@@ -2,8 +2,6 @@ from reinvent_scoring.scoring.score_components.standard.selectivity_component im
 from reinvent_scoring.scoring.score_components.standard.custom_alerts_component import CustomAlerts
 from reinvent_scoring.scoring.score_components.standard.jaccard_distance import JaccardDistance
 from reinvent_scoring.scoring.score_components.standard.matching_substructure import MatchingSubstructure
-from reinvent_scoring.scoring.score_components.standard.parallel_rocs_similarity import ParallelRocsSimilarity
 from reinvent_scoring.scoring.score_components.standard.predictive_property_component import PredictivePropertyComponent
 from reinvent_scoring.scoring.score_components.standard.qed_score import QedScore
-from reinvent_scoring.scoring.score_components.standard.rocs_similarity import RocsSimilarity
 from reinvent_scoring.scoring.score_components.standard.tanimoto_similarity import TanimotoSimilarity
